// $Id: IncorrectDomainIndication.java,v 1.11 2003/03/11 22:55:58 drager Exp $

package org.daml.validator.indications;

import com.hp.hpl.mesa.rdf.jena.model.Resource;
import com.hp.hpl.mesa.rdf.jena.model.Statement;
import com.hp.hpl.mesa.rdf.jena.model.RDFException;
import java.util.*;

/**
 * Indication used for domain restriction violations.
 */
public class IncorrectDomainIndication extends Indication {

    /**
     * The domain restriction on the predicate.
     */
    private java.lang.Object expectedDomain;

    /**
     * The type of the subject in the tested statement.
     */
    private java.util.Collection foundDomains;

    /**
     * The statement with the incorrect domain.
     */
    Statement statement;

    
    public static int defaultLevel = Indication.WARNING;
    
    /**
     * Constuctor function.
     * @param statement	The statement that violates the domain restriction.
     * @param expected	The expected domain type (DAMLModelImpl.Node).
     * @param found	The subject types (Collection of DAMLModelImpl.Node).
     */
    public IncorrectDomainIndication(Statement statement, org.daml.validator.model.DAMLModelImpl.Node expected, java.util.Collection found) 
    {
	super();
	expectedDomain = expected;
	foundDomains = found;
	this.statement = statement;
	type = "Domain Type Mismatch";
	level = defaultLevel;
    }	

    public IncorrectDomainIndication(Statement statement, Resource expected, java.util.Collection found) 
    {
	super();
	expectedDomain = expected;
	foundDomains = found;
	this.statement = statement;
	type = "Domain Type Mismatch";
	level = defaultLevel;
    }	

    public String getMessage() 
    {	
	String m = "";
	if (expectedDomain != null) {
	    m = "Use of this property implies that subject is of type "+expectedDomain+".";
	    if (foundDomains != null) {
		m += "  (Subject is declared type "+foundDomains+")";
	    }
	}
	return(m);
    }

    public String getLocation()
    {
	return(getLocation(statement));
    }

    public String getLocationXML()
	throws RDFException
    {
	return(getLocationXML(statement));
    }


}
