// $Id: TypedLiteralValueIndication.java,v 1.2 2002/08/05 19:03:09 drager Exp $

package org.daml.validator.indications;

import com.hp.hpl.mesa.rdf.jena.model.*;
import java.util.*;

/**
 * Indication used for typed literals whose value does not match the datatype.
 */
public class TypedLiteralValueIndication extends Indication {

    /**
     * The datatype of the typed literal.
     */
    Resource datatype;

    /**
     * The value of the typed literal.
     */
    Collection values;

    /**
     * The type and value statements used for the location
     */
    Collection statements;

    public static int defaultLevel = Indication.ERROR;


    /**
     * Constructor function.
     * @param datatype The datatype 
     * @param value    The value
     * @param statements The datatype type and value statements (for location)
     */
    public TypedLiteralValueIndication(Resource datatype, Collection values, Set statements)
    { 
	super();
	this.datatype = datatype;
	this.values = values;
	this.statements = statements;
	if (values.isEmpty()) {
	    type = "Missing Value";
	} else {
	    type = "Extra Values";
	}
	level = defaultLevel;
    }


    public String getMessage()
    {
	String m = "";
	if (values.isEmpty()) {
	    m = "Typed Literal ("+datatype+") has no value.";
	} else {
	    m = "Typed Literal ("+datatype+") has more than one value: "+values;
	}
	return m;
    }
    

    public String getLocation()
    {
	return(getLocation(statements));
    }

    public String getLocationXML()
	throws RDFException
    {
	return getLocationXML(statements);
    }

}
